@@ -77,6 +77,10 @@ struct _PgmCanvas {
   gulong pixel_formats;
 
   /*< private >*/
+
+  /* for picking */
+  PgmDrawable *entered_emission_stopper;
+
   /* Padding */
   gpointer _pgm_reserved[PGM_PADDING];
 };
@@ -151,14 +155,19 @@ PgmError   pgm_canvas_get_pixel_formats (PgmCanvas *canvas,
 
 /* Protected methods */
 
-void       _pgm_canvas_update_order         (PgmCanvas *canvas,
-                                             PgmDrawable *drawable);
+void         _pgm_canvas_update_order                 (PgmCanvas *canvas,
+                                                       PgmDrawable *drawable);
 
-void       _pgm_canvas_add_pixel_formats    (PgmCanvas *canvas,
-                                             gulong pixel_formats);
+void         _pgm_canvas_add_pixel_formats            (PgmCanvas *canvas,
+                                                       gulong pixel_formats);
 
-void       _pgm_canvas_remove_pixel_formats (PgmCanvas *canvas,
-                                             gulong pixel_formats);
+void         _pgm_canvas_remove_pixel_formats         (PgmCanvas *canvas,
+                                                       gulong pixel_formats);
+
+PgmDrawable *_pgm_canvas_get_entered_emission_stopper (PgmCanvas *canvas);
+
+void         _pgm_canvas_set_entered_emission_stopper (PgmCanvas *canvas,
+                                                       PgmDrawable *drawable);
 
 G_END_DECLS
 
