@@ -165,6 +165,7 @@ static const GEnumValue _pgm_event_type_values[] = {
   { PGM_DRAG_DROP, "PGM_DRAG_DROP", "drag-drop" },
   { PGM_DRAG_LEAVE, "PGM_DRAG_LEAVE", "drag-leave" },
   { PGM_SCROLL, "PGM_SCROLL", "scroll" },
+  { PGM_STATE, "PGM_STATE", "state" },
   { PGM_DELETE, "PGM_DELETE", "delete" },
   { PGM_WIN32_MESSAGE, "PGM_WIN32_MESSAGE", "win32-message" },
   { 0, NULL, NULL }
@@ -236,6 +237,22 @@ pgm_scroll_direction_get_type (void)
   return type;
 }
 
+static const GFlagsValue _pgm_viewport_state_values[] = {
+  { PGM_VIEWPORT_ICONIFIED, "PGM_VIEWPORT_ICONIFIED", "iconified" },
+  { 0, NULL, NULL }
+};
+
+GType
+pgm_viewport_state_get_type (void)
+{
+  static GType type = 0;
+
+  if (!type)
+    type = g_flags_register_static ("PgmViewportState", _pgm_viewport_state_values);
+
+  return type;
+}
+
 
 /* enumerations from "./pgmimage.h" */
 #include "./pgmimage.h"
