@@ -717,6 +717,28 @@ do_visibility (PgmContext *context,
   pgm_backend_set_visibility (context->backend, visible);
 }
 
+/* Iconification update task handler */
+static void
+do_iconification (PgmContext *context,
+                  gpointer data)
+{
+  gboolean iconified;
+
+  GST_OBJECT_LOCK (context->glviewport);
+  iconified = PGM_VIEWPORT (context->glviewport)->iconified;
+  GST_OBJECT_UNLOCK (context->glviewport);
+
+  pgm_backend_set_iconified (context->backend, iconified);
+}
+
+/* Focus update task handler */
+static void
+do_focus (PgmContext *context,
+          gpointer data)
+{
+  pgm_backend_focus (context->backend);
+}
+
 /* Cursor update task handler */
 static void
 do_cursor (PgmContext *context,
@@ -1428,6 +1450,9 @@ init_context (PgmContext *context)
     GST_DEBUG_FUNCPTR (do_fullscreen);
   context->task_func[PGM_CONTEXT_VISIBILITY] =
     GST_DEBUG_FUNCPTR (do_visibility);
+  context->task_func[PGM_CONTEXT_ICONIFICATION] =
+    GST_DEBUG_FUNCPTR (do_iconification);
+  context->task_func[PGM_CONTEXT_FOCUS] = GST_DEBUG_FUNCPTR (do_focus);
   context->task_func[PGM_CONTEXT_ALPHA_BLENDING] =
     GST_DEBUG_FUNCPTR (do_alpha_blending);
   context->task_func[PGM_CONTEXT_RESOLUTION] =
