@@ -58,6 +58,8 @@ typedef enum {
   PGM_CONTEXT_DECORATION,     /* Update decoration state */
   PGM_CONTEXT_FULLSCREEN,     /* Update fullscreen state */
   PGM_CONTEXT_VISIBILITY,     /* Update visibility state */
+  PGM_CONTEXT_ICONIFICATION,  /* Update iconification state */
+  PGM_CONTEXT_FOCUS,          /* Update window active state */
   PGM_CONTEXT_ALPHA_BLENDING, /* Update alpha blending state */
   PGM_CONTEXT_RESOLUTION,     /* Update desktop resolution */
   PGM_CONTEXT_OPACITY,        /* Update opacity */
