@@ -118,6 +118,29 @@ update_interp (PgmGlesImage *glesimage)
   GST_OBJECT_UNLOCK (image);
 }
 
+/* Updates the wrapping */
+static void
+update_wrapping (PgmGlesImage *glesimage)
+{
+  PgmGlesDrawable *glesdrawable = PGM_GLES_DRAWABLE (glesimage);
+  PgmImage *image = PGM_IMAGE (glesdrawable->drawable);
+  PgmGlesTexture *glestexture = glesimage->texture;
+
+  GST_OBJECT_LOCK (image);
+
+  if (image->wrap_s == PGM_IMAGE_CLAMP)
+    glestexture->wrap_s = PGM_GLES_CLAMP_TO_EDGE;
+  else if (image->wrap_s == PGM_IMAGE_REPEAT)
+    glestexture->wrap_s = PGM_GLES_REPEAT;
+
+  if (image->wrap_t == PGM_IMAGE_CLAMP)
+    glestexture->wrap_t = PGM_GLES_CLAMP_TO_EDGE;
+  else if (image->wrap_t == PGM_IMAGE_REPEAT)
+    glestexture->wrap_t = PGM_GLES_REPEAT;
+
+  GST_OBJECT_UNLOCK (image);
+}
+
 /* Updates the mapping (texture) matrix */
 static void
 update_mapping_matrix (PgmGlesImage *glesimage)
@@ -726,6 +749,7 @@ pgm_gles_image_sync (PgmGlesDrawable *glesdrawable)
   /* Synchronize various properties */
   pgm_gles_image_set_fg_color (glesdrawable);
   update_interp (glesimage);
+  update_wrapping (glesimage);
   update_alignment (glesimage);
   update_last_position (glesimage);
   update_drawable_ratio (glesimage);
@@ -742,6 +766,9 @@ pgm_gles_image_sync (PgmGlesDrawable *glesdrawable)
   /* Synchronize the buffer */
   switch (type)
     {
+    case PGM_IMAGE_FILE:
+      pgm_gles_image_set_from_file (glesimage);
+      break;
     case PGM_IMAGE_BUFFER:
       pgm_gles_image_set_from_buffer (glesimage);
       break;
@@ -945,6 +972,53 @@ pgm_gles_image_clear (PgmGlesImage *glesimage)
   GST_OBJECT_UNLOCK (glesimage);
 }
 
+void
+pgm_gles_image_set_from_file (PgmGlesImage *glesimage)
+{
+  PgmGlesDrawable *glesdrawable = PGM_GLES_DRAWABLE (glesimage);
+  PgmImage *image = PGM_IMAGE (glesdrawable->drawable);
+  PgmGlesContextTask *task;
+
+  GST_DEBUG_OBJECT (glesimage, "set_from_file");
+
+  GST_OBJECT_LOCK (image);
+
+  if (G_UNLIKELY (!(image->storage_type == PGM_IMAGE_FILE
+                    || image->storage_type == PGM_IMAGE_IMAGE)))
+    {
+      GST_OBJECT_UNLOCK (image);
+      return;
+    }
+
+  if (image->data.file.pixbuf == NULL)
+    {
+      GST_OBJECT_UNLOCK (image);
+      _pgm_image_stored_from_file_load (image);
+      return;
+    }
+
+  pgm_gles_texture_set_pixbuf (glesimage->texture, image->data.file.pixbuf);
+  pgm_gles_texture_set_matrix (glesimage->texture, image->mapping_matrix);
+
+  GST_OBJECT_UNLOCK (image);
+
+  _pgm_image_stored_from_file_free (image);
+
+  glesimage->empty = FALSE;
+  update_image_ratio (glesimage);
+  update_layout (glesimage);
+  update_slaves (glesimage);
+
+  task = pgm_gles_context_task_new (PGM_GLES_CONTEXT_GEN_TEXTURE,
+                                    glesimage->texture);
+  pgm_gles_context_push_immediate_task (glesdrawable->glesviewport->context,
+                                        task);
+  task = pgm_gles_context_task_new (PGM_GLES_CONTEXT_UPLOAD_TEXTURE,
+                                    glesimage->texture);
+  pgm_gles_context_push_deferred_task (glesdrawable->glesviewport->context,
+                                       task);
+}
+
 void
 pgm_gles_image_set_from_buffer (PgmGlesImage *glesimage)
 {
@@ -1168,6 +1242,22 @@ pgm_gles_image_set_interp (PgmGlesImage *glesimage)
                                         task);
 }
 
+void
+pgm_gles_image_set_wrapping (PgmGlesImage *glesimage)
+{
+  PgmGlesDrawable *glesdrawable = PGM_GLES_DRAWABLE (glesimage);
+  PgmGlesContextTask *task;
+
+  GST_DEBUG_OBJECT (glesimage, "set_wrapping");
+
+  update_wrapping (glesimage);
+
+  task = pgm_gles_context_task_new (PGM_GLES_CONTEXT_UPDATE_TEXTURE,
+                                    glesimage->texture);
+  pgm_gles_context_push_immediate_task (glesdrawable->glesviewport->context,
+                                        task);
+}
+
 void
 pgm_gles_image_set_aspect_ratio (PgmGlesImage *glesimage)
 {
